@@ -3,7 +3,6 @@ from __future__ import annotations
 import abc
 import argparse
 import os
-import shutil
 import sys
 import textwrap
 from dataclasses import dataclass
@@ -21,17 +20,17 @@ from typing import (
     Tuple,
     Type,
     TypeVar,
+    Union,
 )
 
-import class_doc
 from typing_extensions import Annotated, get_args, get_origin, get_type_hints
 
 from . import arg, types
-from .arg import Arg, Cmd, Expander, Param, Positional
+from .arg import Arg, Cmd, Expander, HelpCmd, Param, Positional
 from .collector import Instance
 from .errors import ArgErr, Err, ManyErr, Result, collect
 from .sources import CommandLine, EnvironmentVariables, IniSection, IniSectionSource, Source
-from .util import filter_types_single
+from .util import ClassDoc, filter_types_single
 
 C = TypeVar("C", bound="Config")
 
@@ -57,7 +56,13 @@ class ConfigProcessor(Generic[C]):
         """
         exp_flags = {flag: cmd.inserts() for (flag, cmd) in self.cs.cl_expanders.items()}
         val_flags = frozenset(self.cs.cl_flag_params.keys())
-        return CommandLine.make(self.args, exp_flags, val_flags)
+        cmd_flags = frozenset(self.cs.cl_non_expander_cmds.keys())
+        return CommandLine.make(
+            args=self.args,
+            expanding_flags=exp_flags,
+            flags_followed_by_value=val_flags,
+            command_flags=cmd_flags,
+        )
 
     def environment_variables(self) -> Result[EnvironmentVariables]:
         """
@@ -68,7 +73,7 @@ class ConfigProcessor(Generic[C]):
         """
         return EnvironmentVariables(self.env)
 
-    def process(self) -> Result[C]:
+    def process(self) -> Result[Union[C, Cmd]]:
         """
         Runs the processing
 
@@ -82,6 +87,11 @@ class ConfigProcessor(Generic[C]):
         if isinstance(config_sources, Err):
             return config_sources
         cl, env = config_sources
+
+        for flag, cmd in cs.cl_non_expander_cmds.items():
+            if flag in cl.commands:
+                return cmd
+
         ini_from_env: Result[Sequence[Instance[Sequence[Path]]]] = env[cs.ini_files]
         if isinstance(ini_from_env, Err):
             return ini_from_env
@@ -171,7 +181,7 @@ class ConfigStructure(Generic[C]):
         ini_params: Dict[str, Param[Any]] = {}
         env_params: Dict[str, Param[Any]] = {}
 
-        docs: Mapping[str, Sequence[str]] = class_doc.extract_docs_from_cls_obj(config_type)
+        docs: ClassDoc[C] = ClassDoc.make(config_type)
 
         def format_docstring(seq: Sequence[str]) -> str:
             return textwrap.dedent("\n".join(seq))
@@ -189,7 +199,11 @@ class ConfigStructure(Generic[C]):
                 if param is not None:
                     arg = param
             if arg is not None:
-                help = format_docstring(docs.get(name, []))
+                help_lines = docs[name]
+                if help_lines is None:
+                    help = ""
+                else:
+                    help = "\n".join(help_lines)
                 arg = arg.updated(name, help, config_type.env_prefix_)
                 args.append(arg)
                 if name == "ini_files":
@@ -240,7 +254,7 @@ class ConfigStructure(Generic[C]):
         p = argparse.ArgumentParser(
             prog=self.prog,
             description=self.description,
-            formatter_class=argparse.RawDescriptionHelpFormatter,
+            formatter_class=argparse.RawTextHelpFormatter,
         )
         p._action_groups.pop()
         required = p.add_argument_group("required arguments")
@@ -298,9 +312,9 @@ class Config(abc.ABC):
         cwd: Path = Path.cwd(),
         args: Sequence[str] = sys.argv[1:],
         env: Mapping[str, str] = os.environ,
-    ) -> Result[C]:
+    ) -> Result[Union[C, Cmd]]:
         """
-        Parses multiple information sources, returns a configuration or an error
+        Parses multiple information sources, returns a configuration, a command or an error
 
         Default values are taken from the current working directory, the script command line
         arguments, and the current environment variables.
@@ -339,21 +353,17 @@ class Config(abc.ABC):
             A parsed configuration
         """
         res = cls.parse_command_line_(cwd, args, env)
+        if isinstance(res, cls):
+            return res
         if isinstance(res, Err):
-            try:
-                from rich.console import Console
-                from rich.markdown import Markdown
-
-                console = Console()
-                md = Markdown("\n".join(res.markdown()))
-                console.print(md)
-            except:
-                sz = shutil.get_terminal_size()
-                t = res.markdown()
-                print(textwrap.fill("\n".join(t), width=sz.columns))
+            res.pretty_print()
             cls.get_argument_parser_().print_help()
             sys.exit(1)
-        return res
+        assert isinstance(res, Cmd)  # exhaustiveness checking does not work here
+        # TODO: implement generic cmd mechanism
+        assert isinstance(res, HelpCmd), "Only supported command is HelpCmd"
+        cls.get_argument_parser_().print_help()
+        sys.exit(0)
 
     @classmethod
     def get_argument_parser_(cls: Type[C]) -> argparse.ArgumentParser:
